@@ -14,12 +14,12 @@ log = logging.getLogger(__name__)
 
 class CmdAndroidCheckADB(Command):
 
-    name = "check-adb"
-    modules = ADB_MODULES
-
     def __init__(self, target_path: str = None, results_path: str = None,
-                 ioc_files: list = [], module_name: str = None, serial: str = None,
-                 fast_mode: bool = False):
+                 ioc_files: list = [], module_name: str = None,
+                 serial: str = None, fast_mode: bool = False):
         super().__init__(target_path=target_path, results_path=results_path,
                          ioc_files=ioc_files, module_name=module_name,
                          serial=serial, fast_mode=fast_mode, log=log)
+
+        self.name = "check-adb"
+        self.modules = ADB_MODULES
