@@ -7,8 +7,6 @@ import logging
 
 from .base import AndroidExtraction
 
-log = logging.getLogger(__name__)
-
 
 class SELinuxStatus(AndroidExtraction):
     """This module checks if SELinux is being enforced."""
@@ -17,7 +15,8 @@ class SELinuxStatus(AndroidExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
