@@ -4,6 +4,7 @@
 #   https://license.mvt.re/1.1/
 
 import fnmatch
+import logging
 import os
 from tarfile import TarFile
 
@@ -12,7 +13,19 @@ from mvt.common.module import MVTModule
 
 class BackupExtraction(MVTModule):
     """This class provides a base for all backup extractios modules"""
-    ab = None
+
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
+                         log=log, results=results)
+
+        self.ab = None
+        self.backup_path = None
+        self.tar = None
+        self.files = []
 
     def from_folder(self, backup_path: str, files: list) -> None:
         """
