@@ -9,15 +9,14 @@ from mvt.android.parsers import parse_dumpsys_battery_history
 
 from .base import BugReportModule
 
-log = logging.getLogger(__name__)
-
 
 class BatteryHistory(BugReportModule):
     """This module extracts records from battery daily updates."""
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -36,7 +35,8 @@ class BatteryHistory(BugReportModule):
     def run(self) -> None:
         content = self._get_dumpstate_file()
         if not content:
-            self.log.error("Unable to find dumpstate file. Did you provide a valid bug report archive?")
+            self.log.error("Unable to find dumpstate file. Did you provide "
+                           "a valid bug report archive?")
             return
 
         lines = []
