@@ -9,8 +9,6 @@ from mvt.android.parsers import parse_dumpsys_dbinfo
 
 from .base import BugReportModule
 
-log = logging.getLogger(__name__)
-
 
 class DBInfo(BugReportModule):
     """This module extracts records from battery daily updates."""
@@ -19,7 +17,8 @@ class DBInfo(BugReportModule):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -40,7 +39,8 @@ class DBInfo(BugReportModule):
     def run(self) -> None:
         content = self._get_dumpstate_file()
         if not content:
-            self.log.error("Unable to find dumpstate file. Did you provide a valid bug report archive?")
+            self.log.error("Unable to find dumpstate file. Did you provide a "
+                           "valid bug report archive?")
             return
 
         in_dbinfo = False
