@@ -6,16 +6,72 @@
 import datetime
 import hashlib
 import re
+from typing import Union
 
 
-def convert_mactime_to_unix(timestamp, from_2001: bool = True):
-    """Converts Mac Standard Time to a Unix timestamp.
+def convert_chrometime_to_datetime(timestamp: int) -> int:
+    """Converts Chrome timestamp to a datetime.
+
+    :param timestamp: Chrome timestamp as int.
+    :type timestamp: int
+    :returns: datetime.
+
+    """
+    epoch_start = datetime.datetime(1601, 1, 1)
+    delta = datetime.timedelta(microseconds=timestamp)
+    return epoch_start + delta
+
+
+def convert_datetime_to_iso(datetime: datetime.datetime) -> str:
+    """Converts datetime to ISO string.
+
+    :param datetime: datetime.
+    :type datetime: datetime.datetime
+    :returns: ISO datetime string in YYYY-mm-dd HH:MM:SS.ms format.
+    :rtype: str
+
+    """
+    try:
+        return datetime.strftime("%Y-%m-%d %H:%M:%S.%f")
+    except Exception:
+        return ""
+
+
+def convert_unix_to_utc_datetime(timestamp: Union[int, float, str]) -> datetime.datetime:
+    """Converts a unix epoch timestamp to UTC datetime.
+
+    :param timestamp: Epoc timestamp to convert.
+    :type timestamp: int
+    :returns: datetime.
+
+    """
+    return datetime.datetime.utcfromtimestamp(float(timestamp))
+
+
+def convert_unix_to_iso(timestamp: int) -> str:
+    """Converts a unix epoch to ISO string.
+
+    :param timestamp: Epoc timestamp to convert.
+    :type timestamp: int
+    :returns: ISO datetime string in YYYY-mm-dd HH:MM:SS.ms format.
+    :rtype: str
+
+    """
+    try:
+        return convert_datetime_to_iso(convert_unix_to_utc_datetime(timestamp))
+    except Exception:
+        return ""
+
+
+def convert_mactime_to_datetime(timestamp: Union[int, float],
+                                from_2001: bool = True):
+    """Converts Mac Standard Time to a datetime.
 
     :param timestamp: MacTime timestamp (either int or float).
     :type timestamp: int
     :param from_2001: bool: Whether to (Default value = True)
     :param from_2001: Default value = True)
-    :returns: Unix epoch timestamp.
+    :returns: datetime.
 
     """
     if not timestamp:
@@ -23,7 +79,7 @@ def convert_mactime_to_unix(timestamp, from_2001: bool = True):
 
     # This is to fix formats in case of, for example, SMS messages database
     # timestamp format.
-    if type(timestamp) == int and len(str(timestamp)) == 18:
+    if isinstance(timestamp, int) and len(str(timestamp)) == 18:
         timestamp = int(str(timestamp)[:9])
 
     # MacTime counts from 2001-01-01.
@@ -32,37 +88,25 @@ def convert_mactime_to_unix(timestamp, from_2001: bool = True):
 
     # TODO: This is rather ugly. Happens sometimes with invalid timestamps.
     try:
-        return datetime.datetime.utcfromtimestamp(timestamp)
+        return convert_unix_to_utc_datetime(timestamp)
     except Exception:
         return None
 
 
-def convert_chrometime_to_unix(timestamp: int) -> int:
-    """Converts Chrome timestamp to a Unix timestamp.
+def convert_mactime_to_iso(timestamp: int, from_2001: bool = True):
+    """Wraps two conversions from mactime to iso date.
 
-    :param timestamp: Chrome timestamp as int.
-    :type timestamp: int
-    :returns: Unix epoch timestamp.
-
-    """
-    epoch_start = datetime.datetime(1601, 1, 1)
-    delta = datetime.timedelta(microseconds=timestamp)
-    return epoch_start + delta
-
-
-def convert_timestamp_to_iso(timestamp: str) -> str:
-    """Converts Unix timestamp to ISO string.
-
-    :param timestamp: Unix timestamp.
+    :param timestamp: MacTime timestamp (either int or float).
     :type timestamp: int
+    :param from_2001: bool: Whether to (Default value = True)
+    :param from_2001: Default value = True)
     :returns: ISO timestamp string in YYYY-mm-dd HH:MM:SS.ms format.
     :rtype: str
 
     """
-    try:
-        return timestamp.strftime("%Y-%m-%d %H:%M:%S.%f")
-    except Exception:
-        return None
+
+    return convert_datetime_to_iso(convert_mactime_to_datetime(timestamp,
+                                                               from_2001))
 
 
 def check_for_links(text: str) -> list:
@@ -106,8 +150,8 @@ def keys_bytes_to_string(obj) -> str:
         if isinstance(obj, (tuple, list, set)):
             value = [keys_bytes_to_string(x) for x in obj]
             return value
-        else:
-            return obj
+
+        return obj
 
     for key, value in obj.items():
         if isinstance(key, bytes):
