@@ -15,15 +15,15 @@ log = logging.getLogger(__name__)
 
 class CmdIOSCheckFS(Command):
 
-    name = "check-fs"
-    modules = FS_MODULES + MIXED_MODULES
-
     def __init__(self, target_path: str = None, results_path: str = None,
-                 ioc_files: list = [], module_name: str = None, serial: str = None,
-                 fast_mode: bool = False):
+                 ioc_files: list = [], module_name: str = None,
+                 serial: str = None, fast_mode: bool = False):
         super().__init__(target_path=target_path, results_path=results_path,
                          ioc_files=ioc_files, module_name=module_name,
                          serial=serial, fast_mode=fast_mode, log=log)
 
+        self.name = "check-fs"
+        self.modules = FS_MODULES + MIXED_MODULES
+
     def module_init(self, module):
         module.is_fs_dump = True
