@@ -8,7 +8,7 @@ import os
 import plistlib
 
 from mvt.common.module import DatabaseNotFoundError
-from mvt.ios.versions import latest_ios_version
+from mvt.ios.versions import get_device_desc_from_id, latest_ios_version
 
 from ..base import IOSExtraction
 
@@ -18,7 +18,8 @@ class BackupInfo(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -28,7 +29,8 @@ class BackupInfo(IOSExtraction):
     def run(self) -> None:
         info_path = os.path.join(self.target_path, "Info.plist")
         if not os.path.exists(info_path):
-            raise DatabaseNotFoundError("No Info.plist at backup path, unable to extract device information")
+            raise DatabaseNotFoundError("No Info.plist at backup path, unable "
+                                        "to extract device information")
 
         with open(info_path, "rb") as handle:
             info = plistlib.load(handle)
@@ -42,11 +44,20 @@ class BackupInfo(IOSExtraction):
 
         for field in fields:
             value = info.get(field, None)
-            self.log.info("%s: %s", field, value)
+            # Converting the product type in product name
+            if field == "Product Type" and value:
+                product_name = get_device_desc_from_id(value)
+                if product_name:
+                    self.log.info("%s: %s (%s)", field, value, product_name)
+                else:
+                    self.log.info("%s: %s", field, value)
+            else:
+                self.log.info("%s: %s", field, value)
             self.results[field] = value
 
         if "Product Version" in info:
             latest = latest_ios_version()
             if info["Product Version"] != latest["version"]:
-                self.log.warning("This phone is running an outdated iOS version: %s (latest is %s)",
+                self.log.warning("This phone is running an outdated iOS "
+                                 "version: %s (latest is %s)",
                                  info["Product Version"], latest['version'])
