@@ -5,8 +5,9 @@
 
 import logging
 import plistlib
+from typing import Union
 
-from mvt.common.utils import convert_timestamp_to_iso
+from mvt.common.utils import convert_datetime_to_iso
 
 from ..base import IOSExtraction
 
@@ -21,18 +22,20 @@ class ProfileEvents(IOSExtraction):
     """
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record: dict) -> None:
+    def serialize(self, record: dict) -> Union[dict, list]:
         return {
             "timestamp": record.get("timestamp"),
             "module": self.__class__.__name__,
             "event": "profile_operation",
             "data": f"Process {record.get('process')} started operation "
-                    f"{record.get('operation')} of profile {record.get('profile_id')}"
+                    f"{record.get('operation')} of profile "
+                    f"{record.get('profile_id')}"
         }
 
     def check_indicators(self) -> None:
@@ -73,7 +76,7 @@ class ProfileEvents(IOSExtraction):
             for key, value in event[key].items():
                 key = key.lower()
                 if key == "timestamp":
-                    result["timestamp"] = str(convert_timestamp_to_iso(value))
+                    result["timestamp"] = str(convert_datetime_to_iso(value))
                 else:
                     result[key] = value
 
@@ -87,13 +90,15 @@ class ProfileEvents(IOSExtraction):
             if not events_file_path:
                 continue
 
-            self.log.info("Found MCProfileEvents.plist file at %s", events_file_path)
+            self.log.info("Found MCProfileEvents.plist file at %s",
+                          events_file_path)
 
             with open(events_file_path, "rb") as handle:
                 self.results.extend(self.parse_profile_events(handle.read()))
 
         for result in self.results:
-            self.log.info("On %s process \"%s\" started operation \"%s\" of profile \"%s\"",
+            self.log.info("On %s process \"%s\" started operation \"%s\" "
+                          "of profile \"%s\"",
                           result.get("timestamp"), result.get("process"),
                           result.get("operation"), result.get("profile_id"))
 
