@@ -5,6 +5,7 @@
 
 import logging
 from datetime import datetime
+from typing import Union
 
 from mvt.ios.versions import find_version_by_build
 
@@ -19,12 +20,13 @@ class AnalyticsIOSVersions(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record: dict) -> None:
+    def serialize(self, record: dict) -> Union[dict, list]:
         return {
             "timestamp": record["isodate"],
             "module": self.__class__.__name__,
@@ -44,25 +46,25 @@ class AnalyticsIOSVersions(IOSExtraction):
             if not build:
                 continue
 
-            ts = result.get("isodate", None)
-            if not ts:
+            isodate = result.get("isodate", None)
+            if not isodate:
                 continue
 
             if build not in builds.keys():
-                builds[build] = ts
+                builds[build] = isodate
                 continue
 
-            result_dt = datetime.strptime(ts, dt_format)
+            result_dt = datetime.strptime(isodate, dt_format)
             cur_dt = datetime.strptime(builds[build], dt_format)
 
             if result_dt < cur_dt:
-                builds[build] = ts
+                builds[build] = isodate
 
-        for build, ts in builds.items():
+        for build, isodate in builds.items():
             version = find_version_by_build(build)
 
             self.results.append({
-                "isodate": ts,
+                "isodate": isodate,
                 "build": build,
                 "version": version,
             })
