@@ -23,7 +23,8 @@ class Netusage(NetBase):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -34,8 +35,9 @@ class Netusage(NetBase):
             self.log.info("Found NetUsage database at path: %s", self.file_path)
             try:
                 self._extract_net_data()
-            except sqlite3.OperationalError as e:
-                self.log.info("Skipping this NetUsage database because it seems empty or malformed: %s", e)
+            except sqlite3.OperationalError as exc:
+                self.log.info("Skipping this NetUsage database because "
+                              "it seems empty or malformed: %s", exc)
                 continue
 
         self._find_suspicious_processes()
