@@ -5,8 +5,9 @@
 
 import logging
 import sqlite3
+from typing import Union
 
-from mvt.common.utils import convert_mactime_to_unix, convert_timestamp_to_iso
+from mvt.common.utils import convert_mactime_to_iso
 
 from ..base import IOSExtraction
 
@@ -21,17 +22,19 @@ class SafariFavicon(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record: dict) -> None:
+    def serialize(self, record: dict) -> Union[dict, list]:
         return {
             "timestamp": record["isodate"],
             "module": self.__class__.__name__,
             "event": "safari_favicon",
-            "data": f"Safari favicon from {record['url']} with icon URL {record['icon_url']} ({record['type']})",
+            "data": f"Safari favicon from {record['url']} with icon URL "
+                    f"{record['icon_url']} ({record['type']})",
         }
 
     def check_indicators(self) -> None:
@@ -67,7 +70,7 @@ class SafariFavicon(IOSExtraction):
                 "url": row[0],
                 "icon_url": row[1],
                 "timestamp": row[2],
-                "isodate": convert_timestamp_to_iso(convert_mactime_to_unix(row[2])),
+                "isodate": convert_mactime_to_iso(row[2]),
                 "type": "valid",
                 "safari_favicon_db_path": file_path,
             })
@@ -86,7 +89,7 @@ class SafariFavicon(IOSExtraction):
                 "url": row[0],
                 "icon_url": row[1],
                 "timestamp": row[2],
-                "isodate": convert_timestamp_to_iso(convert_mactime_to_unix(row[2])),
+                "isodate": convert_mactime_to_iso(row[2]),
                 "type": "rejected",
                 "safari_favicon_db_path": file_path,
             })
@@ -96,8 +99,10 @@ class SafariFavicon(IOSExtraction):
 
     def run(self) -> None:
         for file_path in self._get_fs_files_from_patterns(SAFARI_FAVICON_ROOT_PATHS):
-            self.log.info("Found Safari favicon cache database at path: %s", file_path)
+            self.log.info("Found Safari favicon cache database at path: %s",
+                          file_path)
             self._process_favicon_db(file_path)
 
-        self.log.info("Extracted a total of %d favicon records", len(self.results))
+        self.log.info("Extracted a total of %d favicon records",
+                      len(self.results))
         self.results = sorted(self.results, key=lambda x: x["isodate"])
