@@ -4,8 +4,9 @@
 #   https://license.mvt.re/1.1/
 
 import logging
+from typing import Union
 
-from mvt.common.utils import convert_mactime_to_unix, convert_timestamp_to_iso
+from mvt.common.utils import convert_mactime_to_iso
 
 from ..base import IOSExtraction
 
@@ -19,17 +20,19 @@ class ShutdownLog(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record: dict) -> None:
+    def serialize(self, record: dict) -> Union[dict, list]:
         return {
             "timestamp": record["isodate"],
             "module": self.__class__.__name__,
             "event": "shutdown",
-            "data": f"Client {record['client']} with PID {record['pid']} was running when the device was shut down",
+            "data": f"Client {record['client']} with PID {record['pid']} "
+                     "was running when the device was shut down",
         }
 
     def check_indicators(self) -> None:
@@ -46,7 +49,8 @@ class ShutdownLog(IOSExtraction):
             for ioc in self.indicators.get_iocs("processes"):
                 parts = result["client"].split("/")
                 if ioc in parts:
-                    self.log.warning("Found mention of a known malicious process \"%s\" in shutdown.log",
+                    self.log.warning("Found mention of a known malicious "
+                                     "process \"%s\" in shutdown.log",
                                      ioc)
                     result["matched_indicator"] = ioc
                     self.detected.append(result)
@@ -72,8 +76,7 @@ class ShutdownLog(IOSExtraction):
                     except Exception:
                         mac_timestamp = 0
 
-                timestamp = convert_mactime_to_unix(mac_timestamp, from_2001=False)
-                isodate = convert_timestamp_to_iso(timestamp)
+                isodate = convert_mactime_to_iso(mac_timestamp, from_2001=False)
 
                 for current_process in current_processes:
                     self.results.append({
