@@ -8,9 +8,9 @@ import itertools
 import logging
 import plistlib
 import sqlite3
+from typing import Union
 
-from mvt.common.utils import (check_for_links, convert_mactime_to_unix,
-                              convert_timestamp_to_iso)
+from mvt.common.utils import check_for_links, convert_mactime_to_iso
 
 from ..base import IOSExtraction
 
@@ -27,18 +27,20 @@ class Shortcuts(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record: dict) -> None:
+    def serialize(self, record: dict) -> Union[dict, list]:
         found_urls = ""
         if record["action_urls"]:
-            found_urls = "- URLs in actions: {}".format(", ".join(record["action_urls"]))
+            found_urls = f"- URLs in actions: {', '.join(record['action_urls'])}"
+
         desc = ""
         if record["description"]:
-            desc = record["description"].decode('utf-8', errors='ignore')
+            desc = record["description"].decode("utf-8", errors="ignore")
 
         return [{
             "timestamp": record["isodate"],
@@ -111,8 +113,8 @@ class Shortcuts(IOSExtraction):
                 action["urls"] = [url.rstrip("',") for url in extracted_urls]
                 actions.append(action)
 
-            shortcut["isodate"] = convert_timestamp_to_iso(convert_mactime_to_unix(shortcut.pop("created_date")))
-            shortcut["modified_date"] = convert_timestamp_to_iso(convert_mactime_to_unix(shortcut["modified_date"]))
+            shortcut["isodate"] = convert_mactime_to_iso(shortcut.pop("created_date"))
+            shortcut["modified_date"] = convert_mactime_to_iso(shortcut["modified_date"])
             shortcut["parsed_actions"] = len(actions)
             shortcut["action_urls"] = list(itertools.chain(*[action["urls"] for action in actions]))
             self.results.append(shortcut)
