@@ -5,9 +5,9 @@
 
 import logging
 import sqlite3
-from datetime import datetime
+from typing import Union
 
-from mvt.common.utils import convert_timestamp_to_iso
+from mvt.common.utils import convert_unix_to_iso
 
 from ..base import IOSExtraction
 
@@ -22,7 +22,6 @@ AUTH_VALUE_OLD = {
     0: "denied",
     1: "allowed"
 }
-
 AUTH_VALUES = {
     0: "denied",
     1: "unknown",
@@ -50,17 +49,21 @@ class TCC(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record: dict) -> None:
+    def serialize(self, record: dict) -> Union[dict, list]:
         if "last_modified" in record:
             if "allowed_value" in record:
-                msg = f"Access to {record['service']} by {record['client']} {record['allowed_value']}"
+                msg = (f"Access to {record['service']} by {record['client']} "
+                       f"{record['allowed_value']}")
             else:
-                msg = f"Access to {record['service']} by {record['client']} {record['auth_value']}"
+                msg = (f"Access to {record['service']} by {record['client']} "
+                       f"{record['auth_value']}")
+
             return {
                 "timestamp": record["last_modified"],
                 "module": self.__class__.__name__,
@@ -68,6 +71,8 @@ class TCC(IOSExtraction):
                 "data": msg
             }
 
+        return {}
+
     def check_indicators(self) -> None:
         if not self.indicators:
             return
@@ -84,18 +89,21 @@ class TCC(IOSExtraction):
         db_version = "v3"
         try:
             cur.execute("""SELECT
-                service, client, client_type, auth_value, auth_reason, last_modified
+                service, client, client_type, auth_value,
+                auth_reason, last_modified
             FROM access;""")
         except sqlite3.OperationalError:
             # v2 version
             try:
                 cur.execute("""SELECT
-                    service, client, client_type, allowed, prompt_count, last_modified
+                    service, client, client_type, allowed,
+                    prompt_count, last_modified
                     FROM access;""")
                 db_version = "v2"
             except sqlite3.OperationalError:
                 cur.execute("""SELECT
-                    service, client, client_type, allowed, prompt_count
+                    service, client, client_type, allowed,
+                    prompt_count
                     FROM access;""")
                 db_version = "v1"
 
@@ -103,18 +111,20 @@ class TCC(IOSExtraction):
             service = row[0]
             client = row[1]
             client_type = row[2]
-            client_type_desc = "bundle_id" if client_type == 0 else "absolute_path"
+            client_type_desc = ("bundle_id" if client_type == 0
+                                    else "absolute_path")
             if db_version == "v3":
                 auth_value = row[3]
                 auth_value_desc = AUTH_VALUES.get(auth_value, "")
                 auth_reason = row[4]
                 auth_reason_desc = AUTH_REASONS.get(auth_reason, "unknown")
-                last_modified = convert_timestamp_to_iso(datetime.utcfromtimestamp((row[5])))
+                last_modified = convert_unix_to_iso(row[5])
 
                 if service in ["kTCCServiceMicrophone", "kTCCServiceCamera"]:
                     device = "microphone" if service == "kTCCServiceMicrophone" else "camera"
-                    self.log.info("Found client \"%s\" with access %s to %s on %s by %s",
-                                  client, auth_value_desc, device, last_modified, auth_reason_desc)
+                    self.log.info("Found client \"%s\" with access %s to %s "
+                                  "on %s by %s", client, auth_value_desc,
+                                  device, last_modified, auth_reason_desc)
 
                 self.results.append({
                     "service": service,
@@ -129,11 +139,13 @@ class TCC(IOSExtraction):
                 allowed_desc = AUTH_VALUE_OLD.get(allowed_value, "")
                 prompt_count = row[4]
                 if db_version == "v2":
-                    last_modified = convert_timestamp_to_iso(datetime.utcfromtimestamp((row[5])))
+                    last_modified = convert_unix_to_iso(row[5])
                     if service in ["kTCCServiceMicrophone", "kTCCServiceCamera"]:
                         device = "microphone" if service == "kTCCServiceMicrophone" else "camera"
-                        self.log.info("Found client \"%s\" with access %s to %s at %s",
-                                      client, allowed_desc, device, last_modified)
+                        self.log.info("Found client \"%s\" with access %s to "
+                                      "%s at %s", client, allowed_desc, device,
+                                      last_modified)
+
                     self.results.append({
                         "service": service,
                         "client": client,
@@ -147,6 +159,7 @@ class TCC(IOSExtraction):
                         device = "microphone" if service == "kTCCServiceMicrophone" else "camera"
                         self.log.info("Found client \"%s\" with access %s to %s",
                                       client, allowed_desc, device)
+
                     self.results.append({
                         "service": service,
                         "client": client,
@@ -159,7 +172,8 @@ class TCC(IOSExtraction):
         conn.close()
 
     def run(self) -> None:
-        self._find_ios_database(backup_ids=TCC_BACKUP_IDS, root_paths=TCC_ROOT_PATHS)
+        self._find_ios_database(backup_ids=TCC_BACKUP_IDS,
+                                root_paths=TCC_ROOT_PATHS)
         self.log.info("Found TCC database at path: %s", self.file_path)
         self.process_db(self.file_path)
 
