@@ -3,12 +3,11 @@
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
-import datetime
 import logging
 import os
 import sqlite3
 
-from mvt.common.utils import convert_timestamp_to_iso
+from mvt.common.utils import convert_unix_to_iso
 
 from ..base import IOSExtraction
 
@@ -20,12 +19,14 @@ WEBKIT_RESOURCELOADSTATICS_ROOT_PATHS = [
 
 
 class WebkitResourceLoadStatistics(IOSExtraction):
-    """This module extracts records from WebKit ResourceLoadStatistics observations.db."""
+    """This module extracts records from WebKit ResourceLoadStatistics
+    observations.db."""
     # TODO: Add serialize().
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -48,7 +49,8 @@ class WebkitResourceLoadStatistics(IOSExtraction):
                         self.detected[key].append(item)
 
     def _process_observations_db(self, db_path, key):
-        self.log.info("Found WebKit ResourceLoadStatistics observations.db file at path %s", db_path)
+        self.log.info("Found WebKit ResourceLoadStatistics observations.db "
+                      "file at path %s", db_path)
 
         self._recover_sqlite_db_if_needed(db_path)
 
@@ -69,11 +71,12 @@ class WebkitResourceLoadStatistics(IOSExtraction):
                 "registrable_domain": row[1],
                 "last_seen": row[2],
                 "had_user_interaction": bool(row[3]),
-                "last_seen_isodate": convert_timestamp_to_iso(datetime.datetime.utcfromtimestamp(int(row[2]))),
+                "last_seen_isodate": convert_unix_to_iso(row[2]),
             })
 
         if len(self.results[key]) > 0:
-            self.log.info("Extracted a total of %d records from %s", len(self.results[key]), db_path)
+            self.log.info("Extracted a total of %d records from %s",
+                          len(self.results[key]), db_path)
 
     def run(self) -> None:
         if self.is_backup:
@@ -83,8 +86,9 @@ class WebkitResourceLoadStatistics(IOSExtraction):
                     key = f"{backup_file['domain']}/{WEBKIT_RESOURCELOADSTATICS_BACKUP_RELPATH}"
                     if db_path:
                         self._process_observations_db(db_path=db_path, key=key)
-            except Exception as e:
-                self.log.info("Unable to search for WebKit observations.db: %s", e)
+            except Exception as exc:
+                self.log.info("Unable to find WebKit observations.db: %s", exc)
         elif self.is_fs_dump:
             for db_path in self._get_fs_files_from_patterns(WEBKIT_RESOURCELOADSTATICS_ROOT_PATHS):
-                self._process_observations_db(db_path=db_path, key=os.path.relpath(db_path, self.target_path))
+                db_rel_path = os.path.relpath(db_path, self.target_path)
+                self._process_observations_db(db_path=db_path, key=db_rel_path)
