@@ -7,7 +7,7 @@ import logging
 import os
 import plistlib
 
-from mvt.common.utils import convert_timestamp_to_iso
+from mvt.common.utils import convert_datetime_to_iso
 
 from ..base import IOSExtraction
 
@@ -32,7 +32,8 @@ class WebkitSessionResourceLog(IOSExtraction):
 
     def __init__(self, file_path: str = None, target_path: str = None,
                  results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = None, results: list = []) -> None:
+                 log: logging.Logger = logging.getLogger(__name__),
+                 results: list = []) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -57,7 +58,7 @@ class WebkitSessionResourceLog(IOSExtraction):
         if not self.indicators:
             return
 
-        for key, entries in self.results.items():
+        for _, entries in self.results.items():
             for entry in entries:
                 source_domains = self._extract_domains(entry["redirect_source"])
                 destination_domains = self._extract_domains(entry["redirect_destination"])
@@ -92,7 +93,8 @@ class WebkitSessionResourceLog(IOSExtraction):
 
                         redirect_path += ", ".join(destination_domains)
 
-                    self.log.warning("Found HTTP redirect between suspicious domains: %s", redirect_path)
+                    self.log.warning("Found HTTP redirect between suspicious "
+                                     "domains: %s", redirect_path)
 
     def _extract_browsing_stats(self, log_path):
         items = []
@@ -113,8 +115,8 @@ class WebkitSessionResourceLog(IOSExtraction):
                 "subframe_under_origin": item.get("subframeUnderTopFrameOrigins", ""),
                 "subresource_under_origin": item.get("subresourceUnderTopFrameOrigins", ""),
                 "user_interaction": item.get("hadUserInteraction"),
-                "most_recent_interaction": convert_timestamp_to_iso(item["mostRecentUserInteraction"]),
-                "last_seen": convert_timestamp_to_iso(item["lastSeen"]),
+                "most_recent_interaction": convert_datetime_to_iso(item["mostRecentUserInteraction"]),
+                "last_seen": convert_datetime_to_iso(item["lastSeen"]),
             })
 
         return items
@@ -125,13 +127,16 @@ class WebkitSessionResourceLog(IOSExtraction):
                 log_path = self._get_backup_file_from_id(log_file["file_id"])
                 if not log_path:
                     continue
-                self.log.info("Found Safari browsing session resource log at path: %s", log_path)
+
+                self.log.info("Found Safari browsing session resource log at "
+                              "path: %s", log_path)
                 self.results[log_path] = self._extract_browsing_stats(log_path)
         elif self.is_fs_dump:
             for log_path in self._get_fs_files_from_patterns(WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS):
-                self.log.info("Found Safari browsing session resource log at path: %s", log_path)
+                self.log.info("Found Safari browsing session resource log at "
+                              "path: %s", log_path)
                 key = os.path.relpath(log_path, self.target_path)
                 self.results[key] = self._extract_browsing_stats(log_path)
 
-        self.log.info("Extracted records from %d Safari browsing session resource logs",
-                      len(self.results))
+        self.log.info("Extracted records from %d Safari browsing session "
+                      "resource logs", len(self.results))
