@@ -240,16 +240,19 @@ IPHONE_IOS_VERSIONS = [
     {"build": "19D52", "version": "15.3.1"},
     {"build": "19E241", "version": "15.4"},
     {"build": "19E258", "version": "15.4.1"},
-    {"build": "19F77", "version": "15.5"}
+    {"build": "19F77", "version": "15.5"},
+    {"build": "19G71", "version": "15.6"},
 ]
 
 
 def get_device_desc_from_id(identifier: str,
                             devices_list: list = IPHONE_MODELS) -> str:
-    for model in IPHONE_MODELS:
+    for model in devices_list:
         if identifier == model["identifier"]:
             return model["description"]
 
+    return ""
+
 
 def find_version_by_build(build: str) -> str:
     build = build.upper()
@@ -257,6 +260,8 @@ def find_version_by_build(build: str) -> str:
         if build == version["build"]:
             return version["version"]
 
+    return ""
+
 
 def latest_ios_version() -> str:
     return IPHONE_IOS_VERSIONS[-1]
